@@ -155,5 +155,5 @@ class XML(object):
 
     @staticmethod
     def __handle_illegals(data):
-        return str(escape(text)).replace('"', '&quot;').replace("'", '&apos;').replace("’", '&apos;')\
-            .replace(chr(160), ' ')
+        return escape(str(data).replace('"', '&quot;').replace("'", '&apos;').replace("’", '&apos;')\
+            .replace(chr(160), ' '))
